#
# spec file for package dar
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   6000
Name:           dar
Version:        2.7.16
Release:        1.2
Summary:        Backup and Restore Application
License:        SUSE-GPL-2.0+-with-openssl-exception
URL:            https://dar.sourceforge.io/
Source0:        https://dar.edrusb.org/dar.linux.free.fr/Releases/Source_code/dar-%{version}.tar.gz
Source1:        https://dar.edrusb.org/dar.linux.free.fr/Releases/Source_code/dar-%{version}.tar.gz.sig
# http://dar.linux.free.fr/doc/authentification.html
Source2:        %{name}.keyring
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  groff
BuildRequires:  libattr-devel
BuildRequires:  librsync-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(ext2fs)
BuildRequires:  pkgconfig(gpg-error)
BuildRequires:  pkgconfig(gpgme) >= 1.2.0
BuildRequires:  pkgconfig(libargon2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgcrypt)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libthreadar)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
Recommends:     %{name}-doc = %{version}
Recommends:     par
%ifarch %{ix86} x86_64 ppc
BuildRequires:  upx
%endif

%description
Dar (Disk Archive) is a hardware-independent backup solution. Dar uses
catalogs (unlike tar),which it makes it possible to extract a single
file without having to read the entire archive. It is also possible to
create incremental backups. Dar archives can also be created or used
with the libdar library (for example, with KDar, a KDE application).
This package contains the command line tools and documentation.

%package -n libdar64-%{sover}
Summary:        Backup and Restore Application
# We recommend the -lang pack from the library, as the lib itself is also gettextized. The main pack does
# not need the Recommends, as it requires the lib anyway (thus indirectly Recommends the -lang package).
Recommends:     %{name}-lang
Provides:       libdar = 2.7.15
Obsoletes:      libdar < 2.7.15

%description -n libdar64-%{sover}
Dar stands for Disk ARchive and is a hardware independent backup
solution. Dar uses catalogs (unlike tar), so it is possible to extract
a single file without having to read the whole archive, and it is also
possible to create incremental backups.

Dar archives can also be created, or used, via the libdar library (for
example with KDar, a KDE application).

This package contains the library used by Dar and KDar.

%package -n libdar-devel
Summary:        Backup and Restore Application
Requires:       libdar64-%{sover} = %{version}

%description -n libdar-devel
Dar stands for Disk ARchive and is a hardware independent backup
solution. Dar uses catalogs (unlike tar), so it is possible to extract
a single file without having to read the whole archive, and it is also
possible to create incremental backups.

Dar archives can also be created, or used, via the libdar library (with
KDar, a KDE application, for example).

This package contains the library used by Dar and KDar.

%package doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description doc
Documentation package for %{name}

%lang_package

%prep
%autosetup -p1

%build
%configure \
  --with-pic \
  --datadir=%{_defaultdocdir} \
  --disable-static \
  --enable-largefile \
  --disable-dar-static
%make_build

%install
%make_install
# libtool make executables static during installation
# overwrite them with original dynamic linked binaries
install -m 0755 src/dar_suite/.libs/* %{buildroot}%{_bindir}/
find %{buildroot} -type f -name "*.la" -delete -print

# Move the sample scripts to the correct location (otherwise rpmlint will error due to these scripts having execute perms)
mkdir %{buildroot}/%{_defaultdocdir}/%{name}/examples/
mv %{buildroot}/%{_defaultdocdir}/%{name}/samples/* %{buildroot}/%{_defaultdocdir}/%{name}/examples
%fdupes %{buildroot}%{_defaultdocdir}/%{name}
%find_lang %{name}

%ldconfig_scriptlets -n libdar64-%{sover}

%check
# ensure that dynamic linked binaries get installed
file %{buildroot}%{_bindir}/* | grep -q dynamic || exit 1
file %{buildroot}%{_bindir}/* | grep static && exit 1
exit 0

%files
%license COPYING
%doc AUTHORS NEWS TODO ChangeLog
%{_bindir}/dar*
%{_mandir}/man1/dar*.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%files -n libdar64-%{sover}
%license COPYING
%{_libdir}/libdar64.so.%{sover}*
%config(noreplace) %{_sysconfdir}/darrc

%files -n libdar-devel
%license COPYING
%{_includedir}/%{name}/
%{_libdir}/libdar64.so
%{_libdir}/pkgconfig/libdar64.pc

%files doc
%license COPYING
%exclude %{_docdir}/%{name}/{AUTHORS,NEWS,TODO,ChangeLog}
%doc %{_docdir}/%{name}

%changelog
* Sat Feb 22 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.7.16
  * fixed mask building of path exclusion (dar's -P option) when used with
    regular expression (problem met while testing or merging a backup)
  * adding support for progressive report to repairing operation at API level
  * warning before processing to the backup if gnupg signatories are provided
    without any gnupg recipient.
  * fixing bug reporting the following message:
    /Subtracting an "infinint" greater than the first, "infinint" cannot be
    negative/. This was due to duplicated counter decrement while merging two
    archives and overwriting policy drives entry to be removed from the
    resulting archive adding to that, the very specific/rare condition where
    the number of removals exceeds more than the half of kept entries...
  * adding kdf support for repairing operation instead of using the values of
    the archive/backup under reparation.
  * fixing bug in thread_cancellation class that led a canceled thread kept
    being recorded as canceled forever, leading libdar to abort immediately
    when run in a new thread having the the same tid.
  * fixing bug in libdar leading an API call to return zero instead of the
    total size of the backup/archive (not use in dar CLI).
  * applying patch from Gentoo about the "which" command replacement in
    scripts
  * fixing some non-initialized variables as reported by cppcheck tool.
* Sat Aug  3 2024 hui <sturm-fr@web.de>
- Update to version 2.7.15
  * updating libdar about CURLINFO_CONTENT_LENGTH_DOWNLOAD symbol which is
    reported as deprecated by recent libcurl libraries.
  * fixed compilation problem under MacOS Mojave
  * fixed bug that lead the warning about a backup operation about to save
    itself, to not show
  * removing obsolete call to gcry_control(GCRYCTL_ENABLE_M_GUARD) while
    initializing libgcrypt. This led to libgcrypt initialization to fail
    with libgcrypt 1.11 and more recent versions.
  * fixed listing but about "present but unsaved" FSA status
  * fixed dead-lock condition in libdar when used with libcurl > 0.74.0 at
    the end of closing sftp session (undocumented changed behavior in
    libcurl).
* Tue May 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.7.14:
  + Adding safe guard in fichier_libcurl destructor to verify all
    data have been passed to libcurl *and* libcurl has completed
    the writing operation before destroying a fichier_libcurl
    object.
  + Adding support for thread cancellation when interacting with
    libcurl.
  + Updating man page.
  + Fixing some error in the code documentation.
  + updated FAQ.
* Mon Nov 13 2023 Andreas Stieger <andreas.stieger@gmx.de>
- fix Leap 15.6 build (libattr)
* Wed Nov  1 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.7.13:
  * fix bug auto-reported in "slice_layout.cpp line 48" concerning
    isolated catalogs triggered when dar/libdar has been compiled
    with some version gcc (gcc >= 11) with optimizations set.
  * documentation and build system updates
- enable lz4, zstd compression support (boo#1216790)
- enable multi-threading support with libthreadar (boo#1216790)
- package license files
- reduce -devel dependencies
- make -doc noarch
* Sun Sep 17 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.12:
  * fixed bug avoid restoration of binary patch when it was based
    on another binary patch.
  * fixing bug in testing routine that lead regression unseen and
    released in 2.7.11.
  * removed set_unexpected() invocation (not useful for years in
    libdar and incompatible with C++17)
  * fixed generated dynamic libdar binary to include all its
    dependent libraries
  * modified default block size for binary deltas, to be closer
    to what rsync uses (more details in man page).
  * adding support for ronna (10^27) and quetta (10^30) new SI
    prefixes, R and Q respectively
  * fixing bug in infinint class met when extending underlying
    storage by zero bytes
  * avoiding delta sig block size calculation when not necessary
* Mon Jul  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.7.10:
  * displaying the slicing information about the archive of reference
    stored within a isolated catalogue when using -l and -q options
  * cleanup code from obsolete and unused readdir_r invocation
  * fixing display bug in dar_manager (shell_interaction class of libdar)
  * fixing python binding build system with John Goerzen's proposal
  * replacing the deprecated PYBIND11_OVERLOAD_* by PYBIND11_OVERRIDE_*
    equivalents
* Thu Jun 15 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 2.7.9:
  * added sanity check in elastic buffer code upon Sviat89@github
  feedback.
  * fixed bug in block_compressor module found by sviat89 while reading
  the code. Seen its context, it does not seem however to have much
  chance to express and would lead dar/libdar to loop forever
  consuming CPU.
  * adding the misc/dar_static_builder_with_musl_voidlinux.bash script
  which automatically builds dar_static from source code under
  VoidLinux/musl
  * fixing bug concerning the restoration in sequential read mode of a
  backup containing binary patches
  * fixed bug in tuyau_global class that lead to seeking at a wrong
  in sequential read mode and the unability to properly rely on a
  isolated catalogue to read (test/extract/diff) an backup in sequential
  read mode, leading dar to report CRC error.
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 2.7.8:
  * updating code and man page about the way to solve the conflict of
  sequentially reading the archive of reference when binary delta is
  implicitly present for differential/incremental backups
  * added -avc option to surface libcurl verbose messages
  * fixed bug in dar where a sanity check about slice min digit detection
  was applied to the local filesystem when the backup was stored
  remotely, this prevented the reading or remote backups
  * exposing libcurl version to the version output (new API call added
  * remove extra slash (/) found after hostname in URL passed to libcurl
  * fixed self test reported error about mycurl_easyhandle_node.cpp
  * improved error message when libcurl fails to connect to an sftp server
  * fixed bug in libdar in the way libcurl is called for reading a file
  using ftp protocol
  * fixed bug in libdar when asking libcurl the size of the file we are
  writing (libcurl segfaults with ftp protocol). In addition, we now
  record this info during the write process (faster and more efficient).
  * fixed bug met when creating a backup on very close and/or high
  bandwidth ftp and sftp repos with the --hash option set, triggering a
  race condition that led dar to sometime hang unexpectedly.
* Mon Aug  8 2022 Dirk Müller <dmueller@suse.com>
- update to 2.7.7:
  * added support for sequential reading more of sliced backup, to
  accommodate tape support used with slices (at the opposite of dar_split)
  * fixing few typos in doc
  * making libdar more tolerant when calls to fadvise fail
* Tue Jul  5 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.7.6
  * adding -f option to dar_cp
  * adding static version of dar_cp (dar_cp_static) as compilation outcome
  * added FAQ for tape usage with dar
  * fixing error in libdar header file installation
  * fixed bug met when interrupting the creation of a block compressed
    backup (always used by lzo compression and by other algorithm only
    when performing multi-threaded compression)
  * typo fixes in documentation
  * fixed message in lax mode used to obtain from the user the archive format
    when this information is corrupted in the archive.
  * fixing lax mode condition that popped up without being requested
  * fixing bug met when reading slice an special block device by mean of
    a symlink
  * adapting sanity checks to the case of a backup read from a special
    device in sequential-read mode.
  * fixed bug that lead dar to report CRC error while reading a backup
    from a pipe with the help of an isolated catalogue
  * adding -V option to dar_split (was using -v) for homogeneity with
    other commands
* Mon Jun  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.6.15
  * fixed error message formatting error leading message to contain
    garbage in place of system error information.
  * fixing bug (internal error) met while trying restoring files and
    dirs without sufficient write permission on the destination
    directory tree to perform the operation.
  * adding minor feature to avoid restoring Unix sockets (-au)
  * fixing dar-catalogue.dtd
- Update to version 2.6.14
  * fixed bug met when removing slices of an old backup located on
    a remote sftp server
  * fixed bug in cache layer met when writing sliced backup to a
    remote ftp or sftp repository
  * enhancement to the -[ and -] options to work as expected when
    "DOS" formatted text file is provided as a file listing.
- Drop outdated Provides / Obsoletes, RPM will automatically detect
  new dependency of linking packages, as long as -devel package
  does not get renamed or packages use dlopen and manually require it
* Fri Dec 18 2020 Martin Pluskal <mpluskal@suse.com>
- Enable curl and rsync support
* Wed Dec 16 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 2.6.13:
  - fixed compilation warning in testing routine (outside libdar and dar)
  - due to change in autoconf, the --sysconfdir path (which defaults to
    ${prefix}/etc) was read as an empty string, leading dar to look for
    darrc system file at the root of the filesystem (/darrc)
  - fixed bug that should occur in extremely rare conditions (it has been
    discover during 2.7.0 validation process): compression must be used,
    no ciphering, no hashing, file changed at backup time or had a poor
    compression ratio, was not saved at slice boundary, the previous
    entry had an EA saved but no FSA or an unchanged FSA. In such
    conditions are all met, dar tries to resave the file in place, but
    partially or totally overwites the EAs of the previous entry leading
    to archive testing to fail for these EA (though the archive could be
    finished without error).
  - fixed bug met when case insensitive mask is requested (-an option)
    and locale of file to restore or backup is not the one the dar binary
    is run with.
* Wed Sep 16 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 2.6.12:
  - fixed regression met in 2.6.11 when generating encrypted
    archives
  - fixing bug in dar_manager libdar part, met when the two oldest
    entries for a file are recorded as unchanged (differential
    backup)
  - fixed typo in dar_manager man page
  - updated lax mode to ignore encryption flag found in header
    and trailer
  - fixed two opposite bugs in strong encryption code that
    annihilated each other, by chance
  - fixing bug met when merging an archive an re-compressing
    the data with another algorithm that gives a less good result,
    this condition lead the merging operation to fail
    reporting a CRC mismatch
  - improving archive header code to cope with unknown flags
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.6.10:
  - update the configure script to handle some undocumented --enable-*
    options that existed but were not expected to be used.
  - fixed spelling in darrc comments
  - fixed bug in dar_split that could occur in very rare conditions
  - fixed EA support build failure due to what seems to be a change
    in Linux kernel header
  - fixed symbol conflict with s_host of in.h on omniOS platform
* Wed Apr 15 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.6.9
  * too many changes to list, see ChangeLog file
- Drop dar-use-libc-xattr.patch (fixed upstream)
- Drop Group tag
- Spec cleanup
* Wed Jan 24 2018 adrian@suse.de
- fix build for Factory
- update to version 2.5.14
  (relevant parts from upstream)
  - made libgcrypt built-in memory guard be initialized before obtaining
    ligcrypt version, to respect libgcrypt usage (but no problem was seen
    nor reported about this inconsistency)
  - fixed syntax error in XML listing output (EA_entry and Attributes
    tags)
  - fixed bugs in dar_split: cygwin support, filedescriptors were not
    explicitly closed at end of execution, allocating buffer on heap
    rather than in the stack for better size flexibility, avoiding buffer
    size to be greater than SSIZE_MAX.
  - added -s option to dar_split in order to disable the by default SYNC
    write that was used and which caused poor performance. To keep the
    same behavior as the older dar_split (and its poor performances) you
    need now using -s option.
  - dar_split enhancement: added call to syncfs before closing the file
    descriptor in split_output mode
  - fixed bug in dar_split that was did not lead dar_split to completely
    fulfill an device before asking for user to change the media when
    used in split_output mode, this was sometimes leading dar reporting
    file as corrupted at dar_split at media boundary.
  - added feature in dar_split to show the amount of data written since
    the last media change
  - added -az option to automatically nullify negative dates returned from
    the system in the archive under creation (filesystem is not modified)
  - included the birthtime (HFS FSA) into the negative dates handling
  - modified behavior: dar now fails upon unknown option instead of warning
    the option is unknown and thus ignored
  - fixed missing throw in tools.cpp (exception condition was not reported)
  - dar now aborts if a line exceeding 20479 bytes is met in a listing file
  - fixed bug in file listing (-[ option) leading some directories and their
    content to be excluded in a somehow rare condition
  - improved behavior when dar reads a negative date. Instead of aborting
    it now asks the user if it can substitute such value by zero
  - improved behavior when dar is asked to read an archive located in a
    directory that does not exist. DUC file passed to -E option is now
    properly run in that case too and has the possibility for example to
    create that directory and download requested file
  - minor feature: displays the archive header which is never ciphered and
    aborts. This feature is activated while listing archive content and
    adding the -aheader option. This brings the side effect to invert two
    lines in the archive summary (dar -l archive -q) "catalogue size" and
    "user comment".
  - adding date format info for -w option in "dar_manager -h" usage help
  - fixed several mistakes in tools.cpp leading compilation to fail under
    certain environments
  - fixed bug in the filtering mechanism relying on file listing (-[ and
  - ] options) that could not find an entry in the listing upon certain
    condition leading a file not being excluded as requested or not
    included as requested
  - fixed bug: -r option (only more recent overwriting policy) was
    considering a file to be more recent when it had the exact same date as
    the file in place.
  - updating documentation about requirements for compiling dar from sources
  - fixed bug: bug met when restoring of a file that has the immutable
    flag set. Dar/libdar failed restoring such file in the context of
    differential/incremental backup. The fix consists of the removal of the
    immutable flag from filesystem before restoring the new version of the
    file's data, then setting back the immutable flag afterward.
  - updating FAQ with description of the way dar uses lzo compression
    compared to the lzop program
  - fixed bug: aborting an archive was leading to an unreadable archive in
    direct mode, most of the time when strong encryption was used
  - minor new feature: added two flavors of lzo algorithm: lzop-1 and lzop-3
    in order to match compression levels 1 and 3 of the lzop command
  - fixed bug: merging operation could wrongly melt different unrelated hard
    linked inodes when merging using an archive which results from a previous
    merging operation.
  - fixed bug: aborting an archive was sometimes leading to an unreadable
    archive in direct mode (was readable only in --sequential-read mode)
  - fixed bug: libgpgme was only present at linking time of final binaries
    (dar, dar_slave, dar_xform, dar_manager, dar_cp, dar_split), not at
    linking time of libdar, which caused problem under Linux Rosa distro
    where the "no-undefined" flag is passed to the linker.
  - minor new feature: -ay option has been added to display sizes in bytes
    instead of the default which uses the largest possible unit (Kio, Mio,
    and so on.)
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Thu Jan  5 2017 mpluskal@suse.com
- Update to version 2.5.8:
  * support for lzma compression
  * improved backwards api compatibility
  * For extensive list of changes from 2.4.20 to 2.5.8 see provided
    CHANGES file
- Packaging cleanups and dependencies update
* Mon Dec 21 2015 mpluskal@suse.com
- Update to 2.4.20
  * fixed display bug in dar_manager met when using -o option and
  adding options for dar that does not exist for dar_manager
  (like -R option)
  * reactivating disabled (by mistake) optimization for some
  read-only dar manager database operations
  * fixing compilation issue with dar against gcc 4.9.2
  * fixing syntax error in dar_manager message
  * fixing bug that avoided creating an archive at the root of the
  filesystem
- Changes for 2.4.19
  * fixed missing quote in dar_par.dcf which is called by the par2
  directive
  * fixed bug in dar_manager's -u option, not displaying most
  recent files of an archive when they have been marked as
  removed in a more recent archive of the same dar_manager
  database.
  * fixed bug met while restoring in sequential read mode a file
  having several copies (was modified at the time it was saved
  and retry-on-change was set).
* Sat Sep 19 2015 mpluskal@suse.com
- Update to 2.4.18
  * Initial Vector used for strong encryption was set with
    pseudo-random data generated using SHA1 message digest and
    blowfish cipher, which are not available when ligcrypt is
    running in FIPS mode. Since 2.4.18 we now use SHA256 and AES256
    for IV assignment in order to have libdar compatible with FIPS
    mode. For data encryption nothing changes: the cipher specified
    (-K, -J, -$ options on CLI) are used as before.
  * fixing bug met when performing archive isolation in
    sequential-read mode, If an archive corruption or truncated
    archive leads an inode to not have its CRC readable, dar aborts
    and issues a BUG report.
* Sat Mar  7 2015 mpluskal@suse.com
- Use SOURCE instead of %%{_sourcedir}/%%{name}.changes
* Tue Mar  3 2015 mpluskal@suse.com
- Add changelog to sources (necessary for _DATE_ and _TIME_
  macros substitution removal)
* Sun Mar  1 2015 mpluskal@suse.com
- Cleanup spec-file with spec-cleaner
- Use url for source
- Add gpg signature
- Get rid of _DATE_ and _TIME macros
- Update to 2.4.17
  * fixing issue when case insensitive comparison was requested
    and invalid wide char for the current local was met in a
    filename. In such situation the corresponding file was never
    saved before (considering a filesystem error for that file),
    while now the ASCII case insensitivity is used as fallback.
* Sun Jan 18 2015 Led <ledest@gmail.com>
- update to version 2.4.16
  * Extensive changelog can be found in Changelog file
- drop dar-2.4.14-fix-bashisms.patch (fixed in package itself)
* Sun Nov 16 2014 Led <ledest@gmail.com>
- fix bashisms in example scripts
- add patches:
  * dar-2.4.14-fix-bashisms.patch
* Thu Jun 26 2014 zawel1@gmail.com
- update to version 2.4.14
  * Extensive changelog can be found in Changelog file
- drop dar-DARWIN.patch (fixed in package itself)
* Sat Jun 14 2014 tchvatal@suse.com
- Drop unused patch dar.diff. Is replaced by sed in spec.
* Mon Jun  2 2014 crrodriguez@opensuse.org
- Also drop libattr from the -devel package requires
* Mon Jun  2 2014 crrodriguez@opensuse.org
- dar-use-libc-xattr.patch  extended attribute functions
  live in glibc, since approx 10 years and have to be used
  instead of those in libattr whenever the rest of its api is
  not used.
* Mon Aug 19 2013 adrian@suse.de
- fix build with old gettext (SLE 11)
* Mon Aug 19 2013 adrian@suse.de
- enforce and test for dynamic linking. (bnc#835318)
* Mon Jun  3 2013 adrian@suse.de
- update to version 2.4.10
  * Extensive changelog can be found in Changelog file
- enable lzo compression support
- enable strong encryption support via gcrypt
- rename lib package to follow so name change
* Mon Jul  9 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0+-with-openssl-exception
  The developers of dar included a special exception to link against
  openSSL
* Fri Jul  6 2012 dimstar@opensuse.org
- Remove libdar Requires from the devel package: it's not needed.
  Note: this did not cause any issue, as libdar4 provide libdar as
  a symbol.
- Package AUTHORS COPYING NEWS TODO ChangeLog as normal %%doc files,
  without copying them around first.
- Rename libdar-4 subpackage to libdar4, following the SLPP. Change
  the rpm group of libdar to System/Libraries.
- Create a -lang package, which is Recommended by libdar. This
  actually helps in the future when libdar5 would ever come out.
  Currently, due to the language files being part of the library
  package, it would be impossible to install multiple versions.
- Pass --disable-static to configure: no need to build it. And as
  a result, we also do not have to delete it in install again.
- Add fdupes BuildRequires and use it in %%install to link the same
  files together.
- Run spec-cleaner.
* Fri Jul  6 2012 dimstar@opensuse.org
- Add dar-DARWIN.patch: Fix the generation of the installed
  config.h header. Our autotools create a config.h.in which also
  contains #ifned _DARWIN_*, which is matched by the upstream grep
  command, but the matching #endif is not matched... See discussion
  and debug on http://lists.opensuse.org/opensuse-packaging/2012-07/msg00042.html.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue Aug  2 2011 aj@suse.de
- Fix filelist.
* Fri Sep  3 2010 tkedwards@fastmail.com.au
- Build for dar 2.3.10
-from 2.3.6 to 2.3.7:
- fixed bug in dar_manager
- fixed a bug in the statistics calculus of dar_manager
- fixed mistake in API tutorial
- fixed bug in the file filtering based on listing file ( -[ option )
- fixed typo and spelling errors in documentation
- from 2.3.7 to 2.3.8:
- fixed bug concerning elastic buffers used beside strong encryption
- added some speed optimizations
- from 2.3.8 to 2.3.9:
- very little optimization of the reading process of EA
- added -q option to dar
- added licensing exception to allow distribution of dar beside OpenSSL library
- Bug fix: during archive diff (only), dar restore atime of file in the backup
  instead of file in the system before opening it for reading.
- from 2.3.9 to 2.3.10:
- fixed bug in displaying dates [SF 2922417]
- enhanced pseudo-random number generation used in dar
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Sat Feb  2 2008 aj@suse.de
- Do not build test programs statically.
* Thu Jan 31 2008 aj@suse.de
- Remove check for old distribution.
- Remove duplicate files.
- Do not package .la files.
- Do not build dar-static to workaround glibc pthread linkage
  problem.
* Fri Jan 25 2008 adrian@suse.de
- fix open call with O_CREAT and without mode
* Fri Nov  9 2007 adrian@suse.de
- add missing #include
* Tue Nov  6 2007 adrian@suse.de
- fix building
- fix rpmlint errors
* Thu Nov  1 2007 coolo@suse.de
- compile with gcc 4.3
* Thu Nov  1 2007 coolo@suse.de
- update to 2.3.6
- changed displayed message when adding a hard link to an archive while
  performing a differential backup
- added back the possibility to use old blowfish implementation (bfw cipher)
- integrated optimization patch from Sonni Norlov
- updated Swedish translation by Peter Landgren
- updated French translation
- fixed broken Native Language Support in 2.3.x (where x<5)
  from 2.3.5 to 2.3.6
- fixed Makefile.am in src/dar_suite (removed "/" after $(DESTDIR))
- fixed bug in regex mask building when not using ordered masks
- fixing bug that led dar_manager to report no error while some files failed
  to be restored due to command-line for dar being too large.
- fixed bug met when user aborts operation while dar is finalizing archive creation [SF #1800507]
- fixed problem with execvp when dar_manager launches dar
* Fri Jul  6 2007 adrian@suse.de
- update to version 2.3.4
  * fixes a weakness in blowfish encryption (#289994)
  * hard link handling bugfix (2.3.3)
- rename libdar package to libdar-4
* Sun Jun 17 2007 ro@suse.de
- avoid string compare with char literal
* Mon Apr  2 2007 adrian@suse.de
- add libzz2-devel to BuildRequires
- fix dependencies of -devel package
* Sat Mar 31 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Tue Jan 16 2007 adrian@suse.de
- adding strong encryption support
- build with extended attributes support again (broken configure check)
* Tue Jan  9 2007 adrian@suse.de
- update to version 2.3.2 again (kdar seems to be dead and is dropped)
* Tue Nov 14 2006 adrian@suse.de
- initialize variable (#188286)
* Tue Oct 17 2006 dmueller@suse.de
- remove upx require
* Sun Sep 10 2006 dmueller@suse.de
- use RPM_OPT_FLAGS
* Mon Jul 10 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 10 2006 aj@suse.de
- Go back to version 2.2.6 since the only user of dar does not build
  with the new dar package.
* Thu May 18 2006 adrian@suse.de
- update to version 2.3.0 with lots of new features.
- added user_interaction::pause2() method
- added the snapshot feature
- added the Cache Directory Tagging detection feature
- adapted Wesley's patch for a pkgconfig for libdar
- added -[ and -] options (file selection from file listing)
  Important consequence for libdar user programs:
  the fs_root argument is now expanded to full absolute path inside libdar,
  thus the mask you will give for path inclusion/exclusion (the "subtree" argument)
  will be used against full absolute path of files under consideration
  for the operation. Assuming you have fs_root=tmp/A and the current
  directory is /tmp, your mask will be used against strings like
  /var/tmp/A/some/file. (instead of tmp/A/some/file as in the previous API
  version). Things are equal if the fs_root is given an absolute path.
- changed archive format to "05". Due to complete review of EA management.
- upon some signal reception, dar aborts the backup nicely, producing a
  completely formatted archive will all the file saved so far. This archive can
  be take as reference for a further backup to continue the operation at a later
  time.
- dar_manager aborts properly upon certain signal reception (do not let the database
  partially updated).
- dar_slave and dar_xform now recognize when a slicename is given in place of a basename
- reviewed thread_cancellation (API change) for it be possible to cancel several thread at the same time
- prevent some dead-lock situation that can occur when a signal is received inside a critical section
- dar_cp, dar_xform and dar_slave also abort nicely upon signal reception
- dar_manager can now restore files based on a given date (not always the most recent version)
- dar_manager now has an interactive mode (-i option)
- change in API, the warning() method need not be overwritten, but the new protected method
  inherited_warning() must be inherited in its place (same function, same prototype
  as the original warning() method).
- dar_manager features are now part of libdar. API has been completed with theses new features
- added the "last_slice" context (%%c with -E option) when creating an archive
- dar now check a file has not been modified while it was reading it, if so it reports a warning and returns a specific exit code
- remove included gettext from the package (it is more a source of conflict with external gettext and if somebody needs internationalization better is to install libintl/gettext on its own).
- added George Foot feedback about the good backup practice sort guide.
- added -e option to dar_manager
- added the progressive_report feature in the API
- dar can now pause every N slice where N >= 1
- integrated Dave Vasilevsky's patch to support Extended Attributes and file forks under MacOS X
- added method in API for external program be able to list dar_manager databases, their file contents and the statistics
- added the merge/sub-archive feature
- remove [list of path] from command line (-g option is now mandatory)
- added regex expression in filters (-ar/-ag options)
- added -ak option
- added the --comparison-field option (extension of the --ignore-owner option aka -O option)
- added the -af option (backup files more recent than a given date, others are keept as already saved)
- dar now take care that an escape character can be sent when pressing the arrow keys and avoid considering them in this situation
- dar will no refuse to abort if user presses escape when dar asks the user to be ready to write to a new slice
- adapted Wesley Legette's patch for an xml archive listing
- added 'InRef' status for EA (same meaning as the one for file's data)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- 2.2.6 update
* Mon Jan 16 2006 dmueller@suse.de
- 2.2.5 update
* Mon Sep 26 2005 mls@suse.de
- make libdar-devel package require base package
* Mon Jul 25 2005 mmj@suse.de
- fix build
* Fri Jul 15 2005 dmueller@suse.de
- 2.2.2 update
* Mon Apr 25 2005 adrian@suse.de
- fix compile on 64bit with gcc 4
* Mon Apr 11 2005 adrian@suse.de
- update to version 2.2.1
* Mon Jan 31 2005 adrian@suse.de
- update to version 2.2.0
  * thread safe lib
* Wed Nov 17 2004 adrian@suse.de
- update to version 2.1.5
  * gcc 3.4 support, -O1 workaround isn't needed anymore
* Thu Jul 15 2004 adrian@suse.de
- update to version 2.1.4
  * fixes ACL support (#42966)
* Sun Mar  7 2004 adrian@suse.de
- update to version 2.1.1
* Wed Feb 11 2004 adrian@suse.de
- update to final 2.1.0 version
* Sun Feb  8 2004 adrian@suse.de
- update to version 2.1.0_pre5
- optimise only with -O1, that fixes all missing symbol problems ...
* Tue Jan 13 2004 adrian@suse.de
- update to version 2.1.0_pre2
- fix compile issues
* Fri Jan  9 2004 adrian@suse.de
- support and require UPX compression on ia32
* Mon Jan  5 2004 adrian@suse.de
- initial package of version 2.0.4
